%--------------------------------------------------------------------------
% File     : ANA002=IntmedVal-2 : Released v0.2.0, Updated v0.5.1.
% Domain   : Analysis
% Problem  : Intermediate value theorem
% Version  : [Wang & Bledsoe, 1987] axioms.
%            Theorem formulation : Ground form of goal.
% English  : If a function f is continuous in a real closed interval 
%            [a,b], where f(a)<=0 and 0<=f(b), then there exists X 
%            such that f(X) = 0. 

% Refs     : Wang T-C., Bledsoe W.W. (1987), Hierarchical Deduction,
%            Journal of Automated Reasoning 3(1), 35-77.
% Source   : [Wang & Bledsoe, 1987]
% Names    : ivt.lop [SETHEO]

% Status   : 
% Syntax   : Number of clauses           :   18 (   5 non-Horn)(   5 units)
%            Number of literals          :   42 (   0 equality)
%            Number of predicate symbols :    2 (   0 propositions)
%            Number of function symbols  :   10 (   5 constants)
%            Number of variables         :   23 (   0 singletons)
%            Maximal clause size         :    5
%            Maximal term depth          :    3

% Comments : The l comes from an instantiation of the least-up-bound axiom, 
%            which says that there exists a point l such that f(l) = 0.
%--------------------------------------------------------------------------
%----Definition of in an interval
input_clause(in_interval,axiom,
    [++in_interval(Lower,X,Upper),
     --less_than_or_equal(Lower,X),
     --less_than_or_equal(X,Upper)]).

%----Inequality axioms
input_clause(reflexivity_of_less,axiom,
    [++less_than_or_equal(X,X)]).

input_clause(totality_of_less,axiom,
    [++less_than_or_equal(X,Y),
     ++less_than_or_equal(Y,X)]).

input_clause(transitivity_of_less,axiom,
    [++less_than_or_equal(X,Z),
     --less_than_or_equal(X,Y),
     --less_than_or_equal(Y,Z)]).

%----Interpolation axioms
input_clause(interpolation1,axiom,
    [--less_than_or_equal(X,q(Y,X)),
     ++less_than_or_equal(X,Y)]).

input_clause(interpolation2,axiom,
    [--less_than_or_equal(q(X,Y),X),
     ++less_than_or_equal(Y,X)]).

%----Continuity axioms
input_clause(continuity1,axiom,
    [++less_than_or_equal(f(X),zero),
     --less_than_or_equal(X,h(X)),
     --in_interval(lower_bound,X,upper_bound)]).

input_clause(continuity2,axiom,
    [++less_than_or_equal(f(X),zero),
     --less_than_or_equal(Y,X),
     --less_than_or_equal(f(Y),zero),
     ++less_than_or_equal(Y,h(X)),
     --in_interval(lower_bound,X,upper_bound)]).

input_clause(continuity3,axiom,
    [++less_than_or_equal(zero,f(X)),
     --less_than_or_equal(k(X),X),
     --in_interval(lower_bound,X,upper_bound)]).

input_clause(continuity4,axiom,
    [++less_than_or_equal(zero,f(X)),
     --less_than_or_equal(X,Y),
     --less_than_or_equal(zero,f(Y)),
     ++less_than_or_equal(k(X),Y),
     --in_interval(lower_bound,X,upper_bound)]).

%----Least upper bound axioms
input_clause(crossover1,axiom,
    [++less_than_or_equal(X,l),
     --less_than_or_equal(X,upper_bound),
     --less_than_or_equal(f(X),zero)]).

input_clause(crossover2_and_g_function1,axiom,
    [++less_than_or_equal(g(X),upper_bound),
     ++less_than_or_equal(l,X)]).

input_clause(crossover3_and_g_function2,axiom,
    [++less_than_or_equal(f(g(X)),0),
     ++less_than_or_equal(l,X)]).

input_clause(crossover4_and_g_function3,axiom,
    [--less_than_or_equal(g(X),X),
     ++less_than_or_equal(l,X)]).

%----Enpoints of the interval
input_clause(the_interval,hypothesis,
    [++less_than_or_equal(lower_bound,upper_bound)]).

input_clause(lower_mapping,hypothesis,
    [++less_than_or_equal(f(lower_bound),zero)]).

input_clause(upper_mapping,hypothesis,
    [++less_than_or_equal(zero,f(upper_bound))]).

input_clause(prove_there_is_x_which_crosses,theorem,
    [--in_interval(f(l),zero,f(l))]).
%--------------------------------------------------------------------------
