%--------------------------------------------------------------------------
% File     : COL031=StrongFxdPtLO-1 : Released v0.4.0, Updated v0.4.0.
% Domain   : Combinatory Logic
% Problem  : Strong fixed point for L and O
% Version  : [Wos & McCune, 1988a] (equality) axioms.
% English  : The strong fixed point property holds for the set P consisting
%            of the combinators L and O, where (Lx)y = x(yy), (Ox)y = y(xy).

% Refs     : Smullyan, R. M. (1985), To Mock a Mocking Bird and Other
%            Logic Puzzles, Knopf, New York.
%          : McCune W.W., Wos L. (1987), A Case Study in Automated Theorem
%            Proving: Finding Sages in Combinatory Logic, Journal of
%            Automated Reasoning 3(1), 91-107.
%          : Wos L., McCune W.W (1988a), Challenge Problems Focusing on
%            Equality and Combinatory Logic: Evaluating Automated Theorem-
%            Proving Programs, Proceedings of the 9th International
%            Conference on Automated Deduction (Argonne, IL, 1988),
%            (Lecture Notes in Computer Science, 310), 714-729.
%          : McCune W.W. , Wos L. (1988b), Some Fixed Point Problems in
%            Combinatory Logic, AAR Newsletter 10, 7-8.
% Source   : [McCune & Wos, 1988b]
% Names    : 

% Status   : 
% Syntax   : Number of clauses           :    9 (   0 non-Horn)(   4 units)
%            Number of literals          :   15 (  15 equality)
%            Number of predicate symbols :    1 (   0 propositions)
%            Number of function symbols  :    4 (   2 constants)
%            Number of variables         :   19 (   0 singletons)
%            Maximal clause size         :    3
%            Maximal term depth          :    4

% Comments : 
%--------------------------------------------------------------------------
%----Include the axioms of equality
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(l_definition,axiom,
    [++equal(apply(apply(l,X),Y),apply(X,apply(Y,Y)))]).

input_clause(o_definition,axiom,
    [++equal(apply(apply(o,X),Y),apply(Y,apply(X,Y)))]).

input_clause(apply_substitution1,axiom,
    [--equal(A,B),
     ++equal(apply(A,C),apply(B,C))]).

input_clause(apply_substitution2,axiom,
    [--equal(D,E),
     ++equal(apply(F,D),apply(F,E))]).

input_clause(f_substitution1,axiom,
    [--equal(G,H),
     ++equal(f(G),f(H))]).

input_clause(prove_fixed_point,theorem,
    [--equal(apply(Y,f(Y)),apply(f(Y),apply(Y,f(Y))))]).
%--------------------------------------------------------------------------
