%--------------------------------------------------------------------------
% File     : COL063=BT_F-1 : Released v0.8.0, Updated v0.9.1.
% Domain   : Combinatory Logic
% Problem  : Find combinator equivalent to F from B and T
% Version  : [Wos & McCune, 1988] (equality) axioms.
% English  : Construct from B and T alone a combinator that behaves as the
%            combinator F does, where ((Bx)y)z = x(yz), (Tx)y = yx,
%            ((Fx)y)z = (zy)x.

% Refs     : Wos L., Winker S., McCune W.W., Overbeek R., Lusk E. and
%            Stevens R. (1990), Automated Reasoning Contributes to
%            Mathemetics and Logic, In Stickel M.E. (Ed), Proceedings of
%            the 10th International Conference on Automated Deduction
%            (Kaiserslautern, Germany, 1990), (Lecture Notes in Artificial
%            Intelligence, 449), Springer-Verlag, NY, 485-499. Problem CL-4.
% Source   : [Wos & McCune, 1988]
% Names    : CL-4 [Wos, et al., 1990]

% Status   : 
% Syntax   : Number of clauses           :   11 (   0 non-Horn)(   4 units)
%            Number of literals          :   19 (  19 equality)
%            Number of predicate symbols :    1 (   0 propositions)
%            Number of function symbols  :    6 (   2 constants)
%            Number of variables         :   24 (   0 singletons)
%            Maximal clause size         :    3
%            Maximal term depth          :    5

% Comments : 
%--------------------------------------------------------------------------
%----Include the axioms of equality
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(b_definition,axiom,
    [++equal(apply(apply(apply(b,X),Y),Z),apply(X,apply(Y,Z)))]).

input_clause(t_definition,axiom,
    [++equal(apply(apply(t,X),Y),apply(Y,X))]).

input_clause(apply_substitution1,axiom,
    [--equal(C,D),
     ++equal(apply(C,E),apply(D,E))]).

input_clause(apply_substitution2,axiom,
    [--equal(F,G),
     ++equal(apply(H,F),apply(H,G))]).

input_clause(f_substitution1,axiom,
    [--equal(I,J),
     ++equal(f(I),f(J))]).

input_clause(g_substitution1,axiom,
    [--equal(K,L),
     ++equal(g(K),g(L))]).

input_clause(h_substitution1,axiom,
    [--equal(K,L),
     ++equal(h(K),h(L))]).

input_clause(prove_f_combinator,theorem,
    [--equal(apply(apply(apply(X,f(X)),g(X)),h(X)),
apply(apply(h(X),g(X)),f(X)))]).
%--------------------------------------------------------------------------
