%--------------------------------------------------------------------------
% File     : COL065=BT_G-1 : Released v0.8.0, Updated v0.9.1.
% Domain   : Combinatory Logic
% Problem  : Find combinator equivalent to G from B and T
% Version  : [Wos & McCune, 1988] (equality) axioms.
% English  : Construct from B and T alone a combinator that behaves as the
%            combinator G does, where ((Bx)y)z = x(yz), (Tx)y = yx,
%            (((Gx)y)z)w = (xw)(yz)

% Refs     : Wos L., Winker S., McCune W.W., Overbeek R., Lusk E. and
%            Stevens R. (1990), Automated Reasoning Contributes to
%            Mathemetics and Logic, In Stickel M.E. (Ed), Proceedings of
%            the 10th International Conference on Automated Deduction
%            (Kaiserslautern, Germany, 1990), (Lecture Notes in Artificial
%            Intelligence, 449), Springer-Verlag, NY, 485-499. Problem CL-6.
% Source   : [Wos & McCune, 1988]
% Names    : CL-6 [Wos, et al., 1990]

% Status   : 
% Syntax   : Number of clauses           :   12 (   0 non-Horn)(   4 units)
%            Number of literals          :   21 (  21 equality)
%            Number of predicate symbols :    1 (   0 propositions)
%            Number of function symbols  :    7 (   2 constants)
%            Number of variables         :   26 (   0 singletons)
%            Maximal clause size         :    3
%            Maximal term depth          :    6

% Comments : 
%--------------------------------------------------------------------------
%----Include the axioms of equality
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(b_definition,axiom,
    [++equal(apply(apply(apply(b,X),Y),Z),apply(X,apply(Y,Z)))]).

input_clause(t_definition,axiom,
    [++equal(apply(apply(t,X),Y),apply(Y,X))]).

input_clause(apply_substitution1,axiom,
    [--equal(C,D),
     ++equal(apply(C,E),apply(D,E))]).

input_clause(apply_substitution2,axiom,
    [--equal(F,G),
     ++equal(apply(H,F),apply(H,G))]).

input_clause(f_substitution1,axiom,
    [--equal(I,J),
     ++equal(f(I),f(J))]).

input_clause(g_substitution1,axiom,
    [--equal(K,L),
     ++equal(g(K),g(L))]).

input_clause(h_substitution1,axiom,
    [--equal(K,L),
     ++equal(h(K),h(L))]).

input_clause(i_substitution1,axiom,
    [--equal(K,L),
     ++equal(i(K),i(L))]).

input_clause(prove_g_combinator,theorem,
    [--equal(apply(apply(apply(apply(X,f(X)),g(X)),h(X)),i(X)),
apply(apply(f(X),i(X)),apply(g(X),h(X))))]).
%--------------------------------------------------------------------------
