%--------------------------------------------------------------------------
% File     : LAT005=SAMsLem-1 : Released v0.0.0, Updated v0.3.1.
% Domain   : Lattice Theory
% Problem  : SAM's lemma
% Version  : [McCharen, et al., 1976] axioms.
% English  : Let L be a modular lattice with 0 and 1.  Suppose that     
%            A and B are elements of L such that (A v B) and (A ^ B)    
%            both have not necessarily unique complements. Then, (A v B)'
%            = ((A v B)' v ((A ^ B)' ^ B)) ^ ((A v B)' v ((A ^ B)' ^ A)).

% Refs     : Guard J., Oglesby F., Bennet J. and Settle L. (1969),
%            Semi-automated Mathematics, Journal of the ACM 16, 49-62.
%          : McCharen J.D., Overbeek R.A., Wos L.A. (1976), Problems
%            and Experiments for and with Automated Theorem Proving
%            Programs, IEEE Transactions on Computers C-25(8), 773-
%            782. Problem SAM'S Lemma.
% Source   : [ANL]
% Names    : SAMslemma.ver1.in [ANL] 
%          : SAM's lemma [McCharen, et al., 1976]

% Status   : 
% Syntax   : Number of clauses           :   31 (   0 non-Horn)(  19 units)
%            Number of literals          :   63 (   0 equality)
%            Number of predicate symbols :    2 (   0 propositions)
%            Number of function symbols  :   14 (  14 constants)
%            Number of variables         :   66 (   4 singletons)
%            Maximal clause size         :    5
%            Maximal term depth          :    1

% Comments : 
% Bugfixes : v0.2.2 - Clause associativity_of_join1, duplicate name fixed.
%            v0.2.2 - Clause meet_b_and_d, duplicate name fixed.
%--------------------------------------------------------------------------
%----Union of 1 and x is equal to 1 :  (1 v X) = 1
input_clause(join_1_and_x,axiom,
    [++join(1,X,1)]).

%----Union of x with itself is equal to x :  (X v X) = X
input_clause(join_x_and_x,axiom,
    [++join(X,X,X)]).

%----Union of 0 and x is equal to x :  (0 v X) = X
input_clause(join_0_and_x,axiom,
    [++join(0,X,X)]).

%----Intersection of 0 and x is equal to 0 : (0 ^ X) = 0
input_clause(meet_0_and_x,axiom,
    [++meet(0,X,0)]).

%----Intersection of x and itself is equal to x : (X ^ X) = X
input_clause(meet_x_and_x,axiom,
    [++meet(X,X,X)]).

%----Intersection of 1 and x is equal to itself : (1 ^ X) = X
input_clause(meet_1_and_x,axiom,
    [++meet(1,X,X)]).

%----Intersection of x and y , is the same as meet of y and x.
%----  (X ^ Y) = (Y ^ X),
input_clause(commutativity_of_meet,axiom,
    [--meet(X,Y,Z),
     ++meet(Y,X,Z)]).

%----Union of x and y is the same as join of y and x. (X v Y) = (Y v X),
input_clause(commutativity_of_join,axiom,
    [--join(X,Y,Z),
     ++join(Y,X,Z)]).

%----Union of x with the meet of x and y is the same as x.
%----  X v (X ^ Y) = X
input_clause(join_meet,axiom,
    [--meet(X,Y,Z),
     ++join(X,Z,X)]).

%----Intersection  of x with the join of x and y is the same as x.
%----  X ^ (X v Y) = X
input_clause(meet_join,axiom,
    [--join(X,Y,Z),
     ++meet(X,Z,X)]).

%----The operation '^', meet ,is associative  
%----  X ^ (Y ^ Z) = (X ^ Y) ^ Z
input_clause(associativity_of_meet1,axiom,
    [--meet(X,Y,Xy),
     --meet(Y,Z,Yz),
     --meet(X,Yz,Xyz),
     ++meet(Xy,Z,Xyz)]).

input_clause(associativity_of_meet2,axiom,
    [--meet(X,Y,Xy),
     --meet(Y,Z,Yz),
     --meet(Xy,Z,Xyz),
     ++meet(X,Yz,Xyz)]).

%----The operation 'v' is associative X v (Y v Z) = (X v Y) v Z
input_clause(associativity_of_join1,axiom,
    [--join(X,Y,Xy),
     --join(Y,Z,Yz),
     --join(X,Yz,Xyz),
     ++join(Xy,Z,Xyz)]).

input_clause(associativity_of_join2,axiom,
    [--join(X,Y,Xy),
     --join(Y,Z,Yz),
     --join(Xy,Z,Xyz),
     ++join(X,Yz,Xyz)]).

%----(X ^ Z) = X implies that (Z ^ (X v Y)) =  (X v (Y ^ Z)),
input_clause(property_of_join_and_meet1,axiom,
    [--meet(X,Z,X),
     --join(X,Y,X1),
     --meet(Y,Z,Y1),
     --meet(Z,X1,Z1),
     ++join(X,Y1,Z1)]).

input_clause(property_of_join_and_meet2,axiom,
    [--meet(X,Z,X),
     --join(X,Y,X1),
     --meet(Y,Z,Y1),
     --join(X,Y1,Z1),
     ++meet(Z,X1,Z1)]).

%----(X ^ Z) = Z implies that (X ^ (Y v Z)) = (Z v (X ^ Y)),
input_clause(property_of_join_and_meet3,axiom,
    [--meet(X,Z,Z),
     --join(Y,Z,Y1),
     --meet(X,Y,X1),
     --meet(X,Y1,Z1),
     ++join(Z,X1,Z1)]).

input_clause(property_of_join_and_meet4,axiom,
    [--meet(X,Z,Z),
     --join(Y,Z,Y1),
     --meet(X,Y,X1),
     --join(Z,X1,Z1),
     ++meet(X,Y1,Z1)]).

%----Negation of Sams Lemma :
%----The following can be obtained by using the fact that
%----if x v y = 1 and  x ^ y = 0 then x = y'

%----a meet b is equal to c : a ^ b = c
input_clause(meet_a_and_b,theorem,
    [++meet(a,b,c)]).

%----The join of d and c is equal to 1 : d v c = c1
input_clause(join_d_and_c,theorem,
    [++join(d,c,1)]).

%----b meet d is equal to e : b v d = e
input_clause(meet_b_and_d,theorem,
    [++meet(b,d,e)]).

%----a meet e is equal to 0 :  a v e = c0
input_clause(meet_a_and_e,theorem,
    [++meet(a,e,0)]).

%----b join a2 is equal to b2 : b v a2 = b2
input_clause(join_b_and_a2,theorem,
    [++join(b,a2,b2)]).

%----a join b2 is equal to c1 :  (a v b2) = c1
input_clause(join_a_and_b2,theorem,
    [++join(a,b2,1)]).

%----a join b is equal to c2 : (a v b) = c2
input_clause(join_a_and_b,theorem,
    [++join(a,b,c2)]).

%----a2 meet c2 is equal to c0 :  a2 ^ c2 = c0
input_clause(meet_a_and_c2,theorem,
    [++meet(a2,c2,0)]).

%----d meet a is equal to d2 : (d ^ a) = d2
input_clause(meet_d_and_a,theorem,
    [++meet(d,a,d2)]).

%----a2 join d2 is equal to e2 : (a2 v d2) = e2
input_clause(join_a2_and_d2,theorem,
    [++join(a2,d2,e2)]).

%----b meet d is equal to a3 :  (b ^ d) = a3
input_clause(meet_d_and_b,theorem,
    [++meet(d,b,a3)]).

%----a2 join a3 is equal to b3 : (a2 v a3) = b3
input_clause(join_a2_and_a3,theorem,
    [++join(a2,a3,b3)]).

%----the meet of b3 and e2 is not equal to a2 : (b3 ^ e2) <> a2
input_clause(prove_meet_b3_and_e2,theorem,
    [--meet(b3,e2,a2)]).
%--------------------------------------------------------------------------
