%--------------------------------------------------------------------------
% File     : LAT005=SAMsLem-2 : Released v0.0.0, Updated v0.3.1.
% Domain   : Lattice Theory
% Problem  : SAM's lemma
% Version  : Otter axioms : Incomplete & Augmented > Incomplete.
% English  : Let L be a modular lattice with 0 and 1.  Suppose that
%            A and B are elements of L such that (A v B) and (A ^ B)
%            both have not necessarily unique complements. Then, (A v B)'
%            = ((A v B)' v ((A ^ B)' ^ B)) ^ ((A v B)' v ((A ^ B)' ^ A)).     

% Refs     : Guard J., Oglesby F., Bennet J. and Settle L. (1969), 
%            Semi-automated Mathematics, Journal of the ACM 16, 49-62.
% Source   : [OTTER]
% Names    : sam_hyp.in [OTTER]
%          : SAM's lemma [ROO]

% Status   : 
% Syntax   : Number of clauses           :   31 (   0 non-Horn)(  21 units)
%            Number of literals          :   55 (   0 equality)
%            Number of predicate symbols :    2 (   0 propositions)
%            Number of function symbols  :   12 (  12 constants)
%            Number of variables         :   58 (   6 singletons)
%            Maximal clause size         :    5
%            Maximal term depth          :    1

% Comments : Two of the properties of meet and join are omitted. I think
%            they are axioms for ensuring modularity of the lattice.
%          : Redundant commuted versions of the axioms for meet and join 
%            with 0 and 1, are supplied.
%--------------------------------------------------------------------------
input_clause(join_1_and_x,axiom,
    [++join(1,X,1)]).

%----Redundant commuted version
input_clause(join_x_and_1,axiom,
    [++join(X,1,1)]).

input_clause(join_0_and_x,axiom,
    [++join(0,X,X)]).

%----Redundant commuted version
input_clause(join_x_and_0,axiom,
    [++join(X,0,X)]).

input_clause(meet_0_and_x,axiom,
    [++meet(0,X,0)]).

%----Redundant commuted version
input_clause(meet_x_and_0,axiom,
    [++meet(X,0,0)]).

input_clause(meet_1_and_x,axiom,
    [++meet(1,X,X)]).

%----Redundant commuted version
input_clause(meet_x_and_1,axiom,
    [++meet(X,1,X)]).

input_clause(meet_x_and_x,axiom,
    [++meet(X,X,X)]).

input_clause(join_x_and_x,axiom,
    [++join(X,X,X)]).

input_clause(commutativity_of_meet,axiom,
    [--meet(X,Y,Z),
     ++meet(Y,X,Z)]).

input_clause(commutativity_of_join,axiom,
    [--join(X,Y,Z),
     ++join(Y,X,Z)]).

input_clause(join_meet,axiom,
    [--meet(X,Y,Z),
     ++join(X,Z,X)]).

input_clause(meet_join,axiom,
    [--join(X,Y,Z),
     ++meet(X,Z,X)]).

input_clause(associativity_of_meet1,axiom,
    [--meet(X,Y,Xy),
     --meet(Y,Z,Yz),
     --meet(X,Yz,Xyz),
     ++meet(Xy,Z,Xyz)]).

input_clause(associativity_of_meet2,axiom,
    [--meet(X,Y,Xy),
     --meet(Y,Z,Yz),
     --meet(Xy,Z,Xyz),
     ++meet(X,Yz,Xyz)]).

input_clause(associativity_of_join1,axiom,
    [--join(X,Y,Xy),
     --join(Y,Z,Yz),
     --join(X,Yz,Xyz),
     ++join(Xy,Z,Xyz)]).

input_clause(associativity_of_join2,axiom,
    [--join(X,Y,Xy),
     --join(Y,Z,Yz),
     --join(Xy,Z,Xyz),
     ++join(X,Yz,Xyz)]).

input_clause(property_of_join_and_meet1,axiom,
    [--meet(X,Z,X),
     --join(X,Y,X1),
     --meet(Y,Z,Y1),
     --meet(Z,X1,Z1),
     ++join(X,Y1,Z1)]).

input_clause(property_of_join_and_meet2,axiom,
    [--meet(X,Z,X),
     --join(X,Y,X1),
     --meet(Y,Z,Y1),
     --join(X,Y1,Z1),
     ++meet(Z,X1,Z1)]).

%----The [McCharen, et al., 1976] axiomatisation has two more of the above
%----property axioms.

input_clause(meet_a2_and_b2,theorem,
    [--meet(a2,b2,r1)]).

input_clause(meet_a_and_b,theorem,
    [++meet(a,b,c)]).

input_clause(join_c_and_r2,theorem,
    [++join(c,r2,1)]).

input_clause(meet_c_and_r2,theorem,
    [++meet(c,r2,0)]).

input_clause(meet_r2_and_b,theorem,
    [++meet(r2,b,e)]).

input_clause(join_a_and_b,theorem,
    [++join(a,b,c2)]).

input_clause(join_c2_and_r1,theorem,
    [++join(c2,r1,1)]).

input_clause(meet_c2_and_r1,theorem,
    [++meet(c2,r1,0)]).

input_clause(meet_r2_and_a,theorem,
    [++meet(r2,a,d)]).

input_clause(join_r1_and_e,theorem,
    [++join(r1,e,a2)]).

input_clause(join_r1_and_d,theorem,
    [++join(r1,d,b2)]).
%--------------------------------------------------------------------------
