%--------------------------------------------------------------------------
% File     : MSC007=Pigeon-2.004 : Released v0.0.0, Updated v0.6.1.
% Domain   : Miscellaneous
% Problem  : Cook pigeon-hole problem
% Version  : Theorem formulation : 1st order; 4 pigeons.
% English  : Suppose there are N holes and N+1 pigeons to put in the
%            holes. Every pigeon is in a hole and no hole contains
%            more than one pigeon. Prove that this is impossible.

% Refs     : Cook S. and Reckhow R. (1979), The Relative Efficiency
%            of Propositional Proof Systems, Journal of Symbolic
%            Logic 44, 36-50.
%          : Pelletier F.J. (1986), Seventy-Five Problems for Testing 
%            Automatic Theorem Provers, Journal of Automated Reasoning
%            2(2), 191-216.
% Source   : [Pelletier, 1986]
% Names    : Pelletier 73 [Pelletier, 1986]

% Status   : 
% Syntax   : Number of clauses           :   28 (   1 non-Horn)(  17 units)
%            Number of literals          :   50 (  25 equality)
%            Number of predicate symbols :    4 (   0 propositions)
%            Number of function symbols  :    8 (   7 constants)
%            Number of variables         :   24 (   0 singletons)
%            Maximal clause size         :    6
%            Maximal term depth          :    2

% Comments : 
% Bugfixes : v0.6.1 - Renamed from MSC009-2.
%--------------------------------------------------------------------------
%----Include axioms of equality
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(pigeon_substitutivity1,axiom,
    [--equal(K,L),
     --pigeon(K),
     ++pigeon(L)]).

input_clause(hole_of_substitutivity1,axiom,
    [--equal(A,B),
     ++equal(hole_of(A),hole_of(B))]).

input_clause(hole_substitutivity1,axiom,
    [--equal(C,D),
     --hole(C),
     ++hole(D)]).

input_clause(in_substitutivity1,axiom,
    [--equal(E,F),
     --in(E,G),
     ++in(F,G)]).

input_clause(in_substitutivity2,axiom,
    [--equal(H,I),
     --in(J,H),
     ++in(J,I)]).

input_clause(pigeon1,theorem,
    [++pigeon(pigeon1)]).

input_clause(pigeon2,theorem,
    [++pigeon(pigeon2)]).

input_clause(pigeon3,theorem,
    [++pigeon(pigeon3)]).

input_clause(pigeon4,theorem,
    [++pigeon(pigeon4)]).

input_clause(pigeon1_not_pigeon2,theorem,
    [--equal(pigeon1,pigeon2)]).

input_clause(pigeon1_not_pigeon3,theorem,
    [--equal(pigeon1,pigeon3)]).

input_clause(pigeon1_not_pigeon4,theorem,
    [--equal(pigeon1,pigeon4)]).

input_clause(pigeon2_not_pigeon3,theorem,
    [--equal(pigeon2,pigeon3)]).

input_clause(pigeon2_not_pigeon4,theorem,
    [--equal(pigeon2,pigeon4)]).

input_clause(pigeon3_not_pigeon4,theorem,
    [--equal(pigeon3,pigeon4)]).

input_clause(hole1,theorem,
    [++hole(hole1)]).

input_clause(hole2,theorem,
    [++hole(hole2)]).

input_clause(hole3,theorem,
    [++hole(hole3)]).

input_clause(hole1_not_hole2,theorem,
    [--equal(hole1,hole2)]).

input_clause(hole1_not_hole3,theorem,
    [--equal(hole1,hole3)]).

input_clause(hole2_not_hole3,theorem,
    [--equal(hole2,hole3)]).

input_clause(all_holes,theorem,
    [--hole(A),
     ++equal(A,hole1),
     ++equal(A,hole2),
     ++equal(A,hole3)]).

input_clause(each_pigeons_hole1,theorem,
    [--pigeon(B),
     ++hole(hole_of(B))]).

input_clause(each_pigeons_hole2,theorem,
    [--pigeon(B),
     ++in(B,hole_of(B))]).

input_clause(only_one_per_hole,theorem,
    [--hole(C),
     --pigeon(D),
     --pigeon(E),
     --in(D,C),
     --in(E,C),
     ++equal(D,E)]).
%--------------------------------------------------------------------------
