%--------------------------------------------------------------------------
% File     : NUM017=SqRtPrmIrr-1 : Released v0.0.0, Updated v0.9.1.
% Domain   : Number Theory
% Problem  : Sqaure root of this prime is irrational
% Version  : [Robinson, 1963] axioms : Incomplete.
% English  : If a is prime, and a is not b^2/c^2, then the square root
%            of a is irrational.

% Refs     : Wos L.A. (1965), Unpublished notes, Argonne National
%            Laboratory. Problem 26.
%          : Robinson J.A. (1963), Theorem Proving on the Computer,
%            Jounal of the ACM 10(2), ACM Press, New York, NY, 163-174.
%          : Wilson G.A. and Minker J. (1976), Resolution, Refinements, and
%            Search Strategies: A Comparative Study, IEEE Transactions on
%            Computers C-25(8), 782-801.
% Source   : [SPRFN]
% Names    : wos26 [Wilson & Minker, 1976]

% Status   : 
% Syntax   : Number of clauses           :   24 (   0 non-Horn)(   6 units)
%            Number of literals          :   58 (  14 equality)
%            Number of predicate symbols :    4 (   0 propositions)
%            Number of function symbols  :    7 (   5 constants)
%            Number of variables         :   63 (   1 singletons)
%            Maximal clause size         :    4
%            Maximal term depth          :    2

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%--------------------------------------------------------------------------
input_clause(closure_of_product,axiom,
    [++product(A,B,multiply(A,B))]).

input_clause(product_associativity1,axiom,
    [--product(A,B,C),
     --product(D,E,B),
     --product(A,D,F),
     ++product(F,E,C)]).

input_clause(product_associativity2,axiom,
    [--product(A,B,C),
     --product(D,B,E),
     --product(F,D,A),
     ++product(F,E,C)]).

input_clause(product_commutativity,axiom,
    [--product(A,B,C),
     ++product(B,A,C)]).

input_clause(product_left_cancellation,axiom,
    [--product(A,B,C),
     --product(A,D,C),
     ++equal(B,D)]).

input_clause(transitivity_of_divides,axiom,
    [--divides(A,B),
     --divides(C,A),
     ++divides(C,B)]).

input_clause(well_defined_product,axiom,
    [--product(A,B,C),
     --product(A,B,D),
     ++equal(D,C)]).

input_clause(product_substitution1,axiom,
    [--equal(D,B),
     --product(C,A,D),
     ++product(C,A,B)]).

input_clause(product_substitution2,axiom,
    [--equal(D,B),
     --product(C,D,A),
     ++product(C,B,A)]).

input_clause(product_substitution3,axiom,
    [--equal(C,B),
     --product(C,D,A),
     ++product(B,D,A)]).

input_clause(divides_substitution1,axiom,
    [--equal(B,A),
     --divides(C,B),
     ++divides(C,A)]).

input_clause(divides_substitution2,axiom,
    [--equal(A,B),
     --divides(A,C),
     ++divides(B,C)]).

input_clause(prime_substitution,axiom,
    [--equal(A,B),
     --prime(A),
     ++prime(B)]).

input_clause(divides_implies_product,axiom,
    [--divides(A,B),
     ++product(A,second_divided_by_1st(A,B),B)]).

input_clause(product_divisible_by_operand,axiom,
    [--product(A,B,C),
     ++divides(A,C)]).

input_clause(primes_lemma1,axiom,
    [--divides(A,B),
     --product(C,C,B),
     --prime(A),
     ++divides(A,C)]).

input_clause(a_is_prime,hypothesis,
    [++prime(a)]).

input_clause(b_squared,hypothesis,
    [++product(b,b,d)]).

input_clause(c_squared,hypothesis,
    [++product(c,c,e)]).

input_clause(a_times_c_squared_is_not_b_squared,hypothesis,
    [--product(a,e,d)]).

input_clause(prove_there_is_no_common_divisor,theorem,
    [--divides(A,c),
     --divides(A,b)]).
%--------------------------------------------------------------------------
