%--------------------------------------------------------------------------
% File     : SET042=OrdPrXProd-3 : Released v0.0.0, Updated v0.2.2.
% Domain   : Set Theory
% Problem  : Ordered pairs are in cross products
% Version  : [Boyer, et al., 1986] axioms : Augmented.
% English  :

% Refs     : Boyer R., Lusk E., McCune W., Overbeek R., Stickel M. and
%            Wos L. (1986), Set Theory in First-Order Logic: Clauses 
%            for Godel's Axioms,  Journal of Automated Reasoning 2(3), 
%            287-327. Problem lemma 27.
% Source   : [Boyer, et al., 1986]
% Names    : Lemma 27 [Boyer, et al., 1986]

% Status   : 
% Syntax   : Number of clauses           :  295 (  20 non-Horn)(  20 units)
%            Number of literals          :  701 ( 286 equality)
%            Number of predicate symbols :   14 (   0 propositions)
%            Number of function symbols  :   63 (  10 constants)
%            Number of variables         :  796 (  36 singletons)
%            Maximal clause size         :    8
%            Maximal term depth          :    4

% Comments : 
%--------------------------------------------------------------------------
%----Include the axioms of equality
include('Axioms/EQU001-0.ax').
%----Include Godel's set axioms
include('Axioms/SET003-0.ax').
%----Include the equality axioms for Godel's set axioms 
include('Axioms/SET003-0.eq').
%--------------------------------------------------------------------------
%----Previously proved lemmas are added at each step
input_clause(first_components_are_equal,axiom,
    [--little_set(X),
     --little_set(U),
     --equal(ordered_pair(X,Y),ordered_pair(U,V)),
     ++equal(X,U)]).

input_clause(left_cancellation,axiom,
    [--little_set(X),
     --little_set(Y),
     --equal(non_ordered_pair(Z,X),non_ordered_pair(Z,Y)),
     ++equal(X,Y)]).

input_clause(second_components_are_equal,axiom,
    [--little_set(X),
     --little_set(Y),
     --little_set(U),
     --little_set(V),
     --equal(ordered_pair(X,Y),ordered_pair(U,V)),
     ++equal(Y,V)]).

input_clause(two_sets_equal,axiom,
    [--subset(X,Y),
     --subset(Y,X),
     ++equal(X,Y)]).

input_clause(property_of_first,axiom,
    [--little_set(X),
     --little_set(Y),
     ++equal(first(ordered_pair(X,Y)),X)]).

input_clause(property_of_second,axiom,
    [--little_set(X),
     --little_set(Y),
     ++equal(second(ordered_pair(X,Y)),Y)]).

input_clause(first_component_is_small,axiom,
    [--ordered_pair_predicate(X),
     ++little_set(first(X))]).

input_clause(second_component_is_small,axiom,
    [--ordered_pair_predicate(X),
     ++little_set(second(X))]).

input_clause(property_of_singleton_sets,axiom,
    [--little_set(X),
     ++member(X,singleton_set(X))]).

input_clause(ordered_pairs_are_small1,axiom,
    [++little_set(ordered_pair(X,Y))]).

input_clause(ordered_pairs_are_small2,axiom,
    [--ordered_pair_predicate(X),
     ++little_set(X)]).

input_clause(containment_is_transitive,axiom,
    [--subset(X,Y),
     --subset(Y,Z),
     ++subset(X,Z)]).

input_clause(image_and_apply1,axiom,
    [++subset(apply(Xf,Y),sigma(image(singleton_set(Y),Xf)))]).

input_clause(image_and_apply2,axiom,
    [++subset(image(singleton_set(Y),Xf),apply(Xf,Y))]).

input_clause(function_values_are_small,axiom,
    [--function(Y),
     ++little_set(apply(Y,X))]).

input_clause(composition_is_a_relation,axiom,
    [++relation(composition(Y,X))]).

input_clause(range_of_composition,axiom,
    [++subset(range_of(composition(Y,X)),range_of(Y))]).

input_clause(domain_of_composition,axiom,
    [--subset(range_of(X),domain_of(Y)),
     ++equal(domain_of(X),domain_of(composition(Y,X)))]).

input_clause(composition_is_a_function,axiom,
    [--function(X),
     --function(Y),
     ++function(composition(Y,X))]).

input_clause(maps_for_composition,axiom,
    [--maps(Xf,U,V),
     --maps(Xg,V,W),
     ++maps(composition(Xg,Xf),U,W)]).

input_clause(apply_for_functions1,axiom,
    [--little_set(X),
     --little_set(Y),
     --function(Xf),
     --member(ordered_pair(X,Y),Xf),
     ++equal(apply(Xf,X),Y)]).

input_clause(apply_for_functions2,axiom,
    [--function(Xf),
     --member(X,domain_of(Xf)),
     --equal(apply(Xf,X),Y),
     ++member(ordered_pair(X,Y),Xf)]).

input_clause(apply_for_functions3,axiom,
    [--maps(Xf,Xd,Xr),
     --member(X,Xd),
     ++member(apply(Xf,X),Xr)]).

input_clause(apply_for_composition1,axiom,
    [--function(Xf),
     --member(X,domain_of(Xf)),
     ++subset(apply(Xg,apply(Xf,X)),apply(composition(Xg,Xf),X))]).

input_clause(apply_for_composition2,axiom,
    [--function(Xf),
     ++subset(apply(composition(Xg,Xf),X),apply(Xg,apply(Xf,X)))]).

input_clause(apply_for_composition3,axiom,
    [--function(Xf),
     --member(X,domain_of(Xf)),
     ++equal(apply(Xg,apply(Xf,X)),apply(composition(Xg,Xf),X))]).

input_clause(member_of_set_a,hypothesis,
    [++member(a,set_a)]).

input_clause(member_of_set_b,hypothesis,
    [++member(b,set_b)]).

input_clause(prove_ordered_pair_is_in_cross_product,theorem,
    [--member(ordered_pair(a,b),cross_product(set_a,set_b))]).
%--------------------------------------------------------------------------
